@@ -19,6 +19,6 @@ module.exports = {
   log: log,
   debug: function(msg, detail) { log(chalk.green(msg) + detail); },
   info: function(msg, detail) { log(chalk.yellow(msg) + chalk.grey(detail)); },
-  warn: function(msg) { log(chalk.bgYellow.magenta(msg)); },
+  warn: function(msg) { log(chalk.bgWhite.magenta(msg)); },
   error: function(msg) { log(chalk.bgWhite.red(msg)); }
 };
