@@ -1,3 +1,10 @@
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
 var moment            = require('moment'),
     _                 = require('lodash'),
     CFValidationError = require('../validation_error'),
@@ -5,7 +12,7 @@ var moment            = require('moment'),
     TimeSplitter      = require('./time_splitter');
 
 module.exports = function(dateFormat) {
-  var frequency,
+  var timeSplit,
       dateFrom = moment(),
       dateTo = moment();
 
@@ -31,8 +38,8 @@ module.exports = function(dateFormat) {
     return this;
   };
 
-  this.split = function(freq) {
-    frequency = freq;
+  this.split = function(split) {
+    timeSplit = split;
     return this;
   };
 
@@ -41,8 +48,8 @@ module.exports = function(dateFormat) {
       throw new CFValidationError('The to Date (' + dateTo.toString() + ') cannot be before than the from Date (' + dateFrom.toString() + ')');
     }
 
-    return _.map(new TimeSplitter(dateFrom, dateTo).split(frequency), function(period) {
-      return new TimePeriod(period.start.format(dateFormat), period.end.format(dateFormat));
+    return _.map(new TimeSplitter(dateFrom, dateTo).split(timeSplit), function(period) {
+      return new TimePeriod(period, dateFormat);
     });
   };
 };
