@@ -25,22 +25,23 @@ module.exports = function(taskDef, context, helpers) {
     logger.log(outputLines.join("\n"));
   };
 
-  taskDef.addTask('generate-boundaries-file', {
-    parameters: [{ name: 'boundary' }]
+  taskDef.addTask('generate-layer-grouping-file', {
+    parameters: [{ name: 'layerGroup' }]
   }, function() {
-    if (_.isEmpty(context.boundaries)) { return Q(); }
-    var content = _.reduce(context.boundaries, function(lines, boundary) {
-      return lines.concat(_.map(boundary.paths, function(path) { return path + ' => ' + boundary.name; }));
-    }, []).join('\n');
-    return utils.fileSystem.writeToFile(helpers.files.codeBoundaries(), content)
+    del.sync(helpers.files.layerGrouping());
+    if (context.layerGrouping.isEmpty()) {
+      logger.warn('No layer group parameter specified. No grouping file created.');
+      return Q();
+    }
+    return utils.fileSystem.writeToFile(helpers.files.layerGrouping(), context.layerGrouping.toString())
     .then(function() {
-      logger.info('Created: ', helpers.files.codeBoundaries());
+      logger.info('Created: ', helpers.files.layerGrouping());
     });
   });
 
   taskDef.addTask('webserver', { description: 'Start local http server to display graphs' }, function() {
     var script = Path.resolve(Path.join(appConfig.get('basedir'), 'scripts/webserver.js'));
-    child.execFileSync(script, ['-p', appConfig.get('serverPort'), '-d', context.outputDir], {stdio: 'inherit'});
+    child.execFileSync(script, ['-p', appConfig.get('serverPort'), '-d', context.outputDir], { stdio: 'inherit' });
   });
 
   taskDef.addTask('clean', { description: 'Delete all analysis reports and files' }, function() {
