@@ -1,9 +1,15 @@
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
 var fs        = require('fs'),
     _         = require('lodash'),
     filter    = require('through2-filter'),
     map       = require('through2-map'),
     reduce    = require('through2-reduce'),
-    Q         = require('q'),
     pp        = require('../parallel_processing'),
     reporting = require('../reporting'),
     wordCount = require('../analysers/word_count'),
@@ -12,9 +18,9 @@ var fs        = require('fs'),
 module.exports = function(taskDef, context, helpers) {
   taskDef.addAnalysisTask('commit-message-analysis',
     {
-      description: 'Analyse the frequency of commit message words',
+      description: 'Analyse the number of occurrencies of commit message words',
       reportName: 'commit-messages',
-      parameters: [{ name: 'dateFrom' }, { name: 'dateTo' }, { name: 'frequency' }, { name: 'minWordCount' }],
+      parameters: [{ name: 'dateFrom' }, { name: 'dateTo' }, { name: 'timeSplit' }, { name: 'minWordCount' }],
       reportFile: 'commit-words-data.json'
     }, ['vcs-commit-messages'], function(publisher) {
     return pp.taskExecutor().processAll(utils.arrays.arrayToFnFactory(context.timePeriods, function(timePeriod) {
@@ -113,7 +119,7 @@ module.exports = function(taskDef, context, helpers) {
     };
 
     var authorsCommunicationAnalysis = function() {
-      var outputStream = utils.json.objectToFileStream(
+      return utils.json.objectToFileStream(
         publisher.addReportFileForType('communication-network'),
         helpers.codeMaat.communicationAnalysis(helpers.files.vcsNormalisedLog(context.dateRange))
         .pipe(map.obj(function(entry) {
@@ -130,16 +136,14 @@ module.exports = function(taskDef, context, helpers) {
           }
           return array;
         }, [])));
-
-      return utils.stream.streamToPromise(outputStream);
     };
 
-    return Q.allSettled([authorsCouplingAnalysis(), authorsCommunicationAnalysis()]);
+    return pp.taskExecutor().processAll([authorsCouplingAnalysis, authorsCommunicationAnalysis]);
   });
 
   taskDef.addAnalysisTask('knowledge-map-analysis',
     {
-      description: 'Analyse the distribution and the loss of knowledge amongst developers for each file',
+      description: 'Analyse the distribution and the loss of knowledge amongst developers/teams for each file',
       reportName: 'knowledge-map',
       parameters: [{ name: 'dateFrom' }, { name: 'dateTo' }],
       reportFile: 'knowledge-map-data.json'
