@@ -17,14 +17,14 @@ module.exports = function(taskDef, context, helpers) {
     {
       description: 'Analyse the evolution and the coupling in time of different parts of your system',
       reportName: 'system-evolution',
-      parameters: [{ name: 'dateFrom' }, { name: 'dateTo' }, { name: 'timeSplit' }, { name: 'boundary' }],
+      parameters: [{ name: 'dateFrom' }, { name: 'dateTo' }, { name: 'timeSplit' }, { name: 'layerGroup' }],
       reportFiles: {
         'coupling-trend':  'system-coupling-data.json',
         'churn-trend':     'system-churn-data.json',
         'revisions-trend': 'system-revisions-data.json'
       }
-    }, ['vcs-log-dump', 'generate-boundaries-file'], function(publisher) {
-    var groupParam = _.isEmpty(context.boundaries) ? {} : { '-g': helpers.files.codeBoundaries() };
+    }, ['vcs-log-dump', 'generate-layer-grouping-file'], function(publisher) {
+    var groupParam = context.layerGrouping.isEmpty() ? {} : { '-g': helpers.files.layerGrouping() };
 
     var runAnalysis = function(analysis, reportFile, streamTransform) {
       var stream = pp.objectStreamCollector()
@@ -36,7 +36,7 @@ module.exports = function(taskDef, context, helpers) {
       return utils.stream.streamToPromise(utils.json.objectArrayToFileStream(reportFile, stream));
     };
 
-    if (_.isEmpty(context.boundaries)) {
+    if (context.layerGrouping.isEmpty()) {
       return Q.allSettled(_.map([
         [
           'revisionsAnalysis',
